@@ -9,10 +9,10 @@
 #include <QtCore/QDateTime>
 #include <Soprano/Vocabulary/RDF>
 
-#include <dms-copy/simpleresource.h>
+#include <nepomuk2/simpleresource.h>
 
 #include "nmo/message.h"
-namespace Nepomuk {
+namespace Nepomuk2 {
 namespace NMO {
 /**
  * A message sent with Instant Messaging software. 
@@ -20,7 +20,7 @@ namespace NMO {
 class IMMessage : public NMO::Message
 {
 public:
-    IMMessage(Nepomuk::SimpleResource* res)
+    IMMessage(Nepomuk2::SimpleResource* res)
       : NMO::Message(res), m_res(res)
     {}
 
@@ -30,7 +30,7 @@ protected:
     virtual QUrl resourceType() const { return QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nmo#IMMessage", QUrl::StrictMode); }
 
 private:
-    Nepomuk::SimpleResource* m_res;
+    Nepomuk2::SimpleResource* m_res;
 };
 }
 }
