@@ -52,6 +52,8 @@ using namespace Akonadi;
 using KPIM::Maildir;
 using namespace Akonadi_Maildir_Resource;
 
+#define CLEANER_TIMEOUT 2*6000
+
 Maildir MaildirResource::maildirForCollection( const Collection& col )
 {
   const QString path = maildirPathForCollection( col );
@@ -140,6 +142,9 @@ MaildirResource::MaildirResource( const QString &id )
   } else {
      synchronizeCollectionTree();
   }
+
+  mChangedCleanerTimer = new QTimer( this );
+  connect( mChangedCleanerTimer, SIGNAL( timeout() ), this, SLOT( changedCleaner() ) );
 }
 
 void MaildirResource::attemptConfigRestoring( KJob * job )
@@ -282,6 +287,8 @@ void MaildirResource::itemAdded( const Akonadi::Item & item, const Akonadi::Coll
     stopMaildirScan( dir );
 
     const QString rid = dir.addEntry( mail->encodedContent() );
+    mChangedFiles.insert( rid );
+    mChangedCleanerTimer->start( CLEANER_TIMEOUT );
 
     restartMaildirScan( dir );
 
@@ -355,6 +362,12 @@ void MaildirResource::itemChanged( const Akonadi::Item& item, const QSet<QByteAr
             data = mail->encodedContent();
           }
           dir.writeEntry( newItem.remoteId(), data );
+          mChangedFiles.insert( newItem.remoteId() );
+          mChangedCleanerTimer->start( CLEANER_TIMEOUT );
+        } else {
+            restartMaildirScan( dir );
+            cancelTask( i18n( "Error: Unsupported type." ) );
+            return;
         }
       }
 
@@ -396,6 +409,9 @@ void MaildirResource::itemMoved( const Item &item, const Collection &source, con
 
   const QString newRid = sourceDir.moveEntryTo( item.remoteId(), destDir );
 
+  mChangedFiles.insert( newRid );
+  mChangedCleanerTimer->start( CLEANER_TIMEOUT );
+
   restartMaildirScan( sourceDir );
   restartMaildirScan( destDir );
 
@@ -685,7 +701,7 @@ void MaildirResource::slotDirChanged(const QString& dir)
 {
   QFileInfo fileInfo( dir );
   if ( fileInfo.isFile() ) {
-    slotFileChanged( dir );
+    slotFileChanged( fileInfo );
     return;
   }
 
@@ -733,11 +749,14 @@ void MaildirResource::fsWatchDirFetchResult(KJob* job)
   synchronizeCollection( cols.first().id() );
 }
 
-void MaildirResource::slotFileChanged( const QString& fileName )
+void MaildirResource::slotFileChanged( const QFileInfo& fileInfo )
 {
-  QFileInfo fileInfo( fileName );
+  const QString key = fileInfo.fileName();
+  if ( mChangedFiles.contains( key ) ) {
+    mChangedFiles.remove( key );
+    return;
+  }
 
-  QString key = fileInfo.fileName();
   QString path = fileInfo.path();
   if ( path.endsWith( QLatin1String( "/new" ) ) ) {
     path.remove( path.length() - 4, 4 );
@@ -836,4 +855,9 @@ void MaildirResource::restartMaildirScan(const Maildir &maildir)
     mFsWatcher->restartDirScan( path + QLatin1Literal( "/cur" ) );
 }
 
+void MaildirResource::changedCleaner()
+{
+    mChangedFiles.clear();
+}
+
 #include "maildirresource.moc"
